"""Doc string"""
from something import anythin
from anything import something
_tr = Translator("Orange", "biolab.si", "Orange")
del Translator

import os

class A:
    '''Doc string'''

    a = "A class attribute"

    def f(self, x=_tr.e(_tr.c(2, "default"))):
        "Doc string"

        t = os.listdir(_tr.e(_tr.c(3, "some/directory")))
        for x in t:
            print(_tr.e(_tr.c(4, f"File {x}")))
            print(_tr.e(_tr.c(5, f'Not file {x + ".bak"}')))
            if x.endswith(_tr.e(_tr.c(6, f"""{"nonsense"}"""))):
                return x

if __name__ == "__main__":
    print("Please don't run this.")
    print(_tr.e(_tr.c(7, 'Import it, if you must.')))


class PigManager:
    def __init__(self, n):
        if not 5 <= n <= 20:
            raise ValueError(
                f"Wrong number: {n} must be between 5 and 20.")
        self.n = n

    def walk(self):
        print(f"{self.n} little pigs went for a walk")



"""Doc string"""

import os

class A:
    '''Doc string'''

    a = "A class attribute"

    def f(self, x="default"):
        "Doc string"

        t = os.listdir("some/directory")
        for x in t:
            print(f"Datoteka {x}")
            print(f'Ne datoteka {x + ".bak"}')
            if x.endswith(f"""{"nesmisel"}"""):
                return x

if __name__ == "__main__":
    print("Please don't run this.")
    print('Import it, if you must.')


from farm.pigs import PigManager

def main():
    print("This program serves no useful purpose.")
    ns = input("Enter a number between 5 and 20: ")
    try:
        n = int(ns)
    except ValueError:
        print(f"'{n}' is not a number.")
    else:
        farm = PigManager(n)
        farm.walk()

if __name__ == "__main__":
    main()
